==> cherokee-0.4.1.tar.gz: cherokee-0.4.1/src/virtual_server.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001-2003 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __CHEROKEE2_VIRTUAL_SERVER_H__
#define __CHEROKEE2_VIRTUAL_SERVER_H__

#include "common.h"
#include "plugin_table.h"


typedef struct {
	char                    *domain;  /* Domain name. Eg: www.alobbs.com */
	char                    *root;    /* Document root. Eg: /var/www */
	cherokee_plugin_table_t *plugins; /* plugin-to-path. Eg: (/public, common) */
} cherokee_virtual_server_t;

ret_t cherokee_virtual_server_new   (cherokee_virtual_server_t **vserver);
ret_t cherokee_virtual_server_free  (cherokee_virtual_server_t  *vserver);
ret_t cherokee_virtual_server_clean (cherokee_virtual_server_t  *vserver);

ret_t cherokee_virtual_server_set  (cherokee_virtual_server_t  *vserver, char *web_dir, char *handler);

#endif /* __CHEROKEE2_VIRTUAL_SERVER_H__ */

==> cherokee-0.4.3-pre2.tar.gz: cherokee-0.4.3/src/virtual_server.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001-2003 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef __CHEROKEE2_VIRTUAL_SERVER_H__
#define __CHEROKEE2_VIRTUAL_SERVER_H__

#include "common.h"
#include "plugin_table.h"
#include "plugin_table_entry.h"


typedef struct {
	char                    *domain;       /* Domain name. Eg: www.alobbs.com */
	cherokee_plugin_table_t *plugins;      /* plugin-to-path. Eg: (/public, common) */

	char                    *root;         /* Document root. Eg: /var/www */
	int                      root_len;     /* Document root length */

} cherokee_virtual_server_t;

ret_t cherokee_virtual_server_new   (cherokee_virtual_server_t **vserver);
ret_t cherokee_virtual_server_free  (cherokee_virtual_server_t  *vserver);
ret_t cherokee_virtual_server_clean (cherokee_virtual_server_t  *vserver);

ret_t cherokee_virtual_server_set   (cherokee_virtual_server_t  *vserver, char *web_dir, char *handler_name, cherokee_plugin_table_entry_t *plugin_entry);

#endif /* __CHEROKEE2_VIRTUAL_SERVER_H__ */
